@@ -58,6 +58,7 @@ from .type_defs import (
     DescribeReportJobOutputTypeDef,
     DescribeReportPlanOutputTypeDef,
     DescribeRestoreJobOutputTypeDef,
+    EmptyResponseMetadataTypeDef,
     ExportBackupPlanTemplateOutputTypeDef,
     FrameworkControlTypeDef,
     GetBackupPlanFromJSONOutputTypeDef,
@@ -152,10 +153,18 @@ class BackupClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_backup/client/#can_paginate)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/backup.html#Backup.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_backup/client/#close)
+        """
+
     def create_backup_plan(
         self,
         *,
-        BackupPlan: "BackupPlanInputTypeDef",
+        BackupPlan: BackupPlanInputTypeDef,
         BackupPlanTags: Mapping[str, str] = ...,
         CreatorRequestId: str = ...
     ) -> CreateBackupPlanOutputTypeDef:
@@ -170,7 +179,7 @@ class BackupClient(BaseClient):
         self,
         *,
         BackupPlanId: str,
-        BackupSelection: "BackupSelectionTypeDef",
+        BackupSelection: BackupSelectionTypeDef,
         CreatorRequestId: str = ...
     ) -> CreateBackupSelectionOutputTypeDef:
         """
@@ -199,7 +208,7 @@ class BackupClient(BaseClient):
         self,
         *,
         FrameworkName: str,
-        FrameworkControls: Sequence["FrameworkControlTypeDef"],
+        FrameworkControls: Sequence[FrameworkControlTypeDef],
         FrameworkDescription: str = ...,
         IdempotencyToken: str = ...,
         FrameworkTags: Mapping[str, str] = ...
@@ -215,8 +224,8 @@ class BackupClient(BaseClient):
         self,
         *,
         ReportPlanName: str,
-        ReportDeliveryChannel: "ReportDeliveryChannelTypeDef",
-        ReportSetting: "ReportSettingTypeDef",
+        ReportDeliveryChannel: ReportDeliveryChannelTypeDef,
+        ReportSetting: ReportSettingTypeDef,
         ReportPlanDescription: str = ...,
         ReportPlanTags: Mapping[str, str] = ...,
         IdempotencyToken: str = ...
@@ -236,7 +245,9 @@ class BackupClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_backup/client/#delete_backup_plan)
         """
 
-    def delete_backup_selection(self, *, BackupPlanId: str, SelectionId: str) -> None:
+    def delete_backup_selection(
+        self, *, BackupPlanId: str, SelectionId: str
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Deletes the resource selection associated with a backup plan that is specified
         by the `SelectionId` .
@@ -245,7 +256,7 @@ class BackupClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_backup/client/#delete_backup_selection)
         """
 
-    def delete_backup_vault(self, *, BackupVaultName: str) -> None:
+    def delete_backup_vault(self, *, BackupVaultName: str) -> EmptyResponseMetadataTypeDef:
         """
         Deletes the backup vault identified by its name.
 
@@ -253,7 +264,9 @@ class BackupClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_backup/client/#delete_backup_vault)
         """
 
-    def delete_backup_vault_access_policy(self, *, BackupVaultName: str) -> None:
+    def delete_backup_vault_access_policy(
+        self, *, BackupVaultName: str
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Deletes the policy document that manages permissions on a backup vault.
 
@@ -261,7 +274,9 @@ class BackupClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_backup/client/#delete_backup_vault_access_policy)
         """
 
-    def delete_backup_vault_lock_configuration(self, *, BackupVaultName: str) -> None:
+    def delete_backup_vault_lock_configuration(
+        self, *, BackupVaultName: str
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Deletes Backup Vault Lock from a backup vault specified by a backup vault name.
 
@@ -269,7 +284,9 @@ class BackupClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_backup/client/#delete_backup_vault_lock_configuration)
         """
 
-    def delete_backup_vault_notifications(self, *, BackupVaultName: str) -> None:
+    def delete_backup_vault_notifications(
+        self, *, BackupVaultName: str
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Deletes event notifications for the specified backup vault.
 
@@ -277,7 +294,7 @@ class BackupClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_backup/client/#delete_backup_vault_notifications)
         """
 
-    def delete_framework(self, *, FrameworkName: str) -> None:
+    def delete_framework(self, *, FrameworkName: str) -> EmptyResponseMetadataTypeDef:
         """
         Deletes the framework specified by a framework name.
 
@@ -285,7 +302,9 @@ class BackupClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_backup/client/#delete_framework)
         """
 
-    def delete_recovery_point(self, *, BackupVaultName: str, RecoveryPointArn: str) -> None:
+    def delete_recovery_point(
+        self, *, BackupVaultName: str, RecoveryPointArn: str
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Deletes the recovery point specified by a recovery point ID.
 
@@ -293,7 +312,7 @@ class BackupClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_backup/client/#delete_recovery_point)
         """
 
-    def delete_report_plan(self, *, ReportPlanName: str) -> None:
+    def delete_report_plan(self, *, ReportPlanName: str) -> EmptyResponseMetadataTypeDef:
         """
         Deletes the report plan specified by a report plan name.
 
@@ -399,7 +418,9 @@ class BackupClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_backup/client/#describe_restore_job)
         """
 
-    def disassociate_recovery_point(self, *, BackupVaultName: str, RecoveryPointArn: str) -> None:
+    def disassociate_recovery_point(
+        self, *, BackupVaultName: str, RecoveryPointArn: str
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Deletes the specified continuous backup recovery point from Backup and releases
         control of that continuous backup to the source service, such as Amazon RDS.
@@ -722,7 +743,9 @@ class BackupClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_backup/client/#list_tags)
         """
 
-    def put_backup_vault_access_policy(self, *, BackupVaultName: str, Policy: str = ...) -> None:
+    def put_backup_vault_access_policy(
+        self, *, BackupVaultName: str, Policy: str = ...
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Sets a resource-based policy that is used to manage access permissions on the
         target backup vault.
@@ -738,7 +761,7 @@ class BackupClient(BaseClient):
         MinRetentionDays: int = ...,
         MaxRetentionDays: int = ...,
         ChangeableForDays: int = ...
-    ) -> None:
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Applies Backup Vault Lock to a backup vault, preventing attempts to delete any
         recovery point stored in or created in a backup vault.
@@ -753,7 +776,7 @@ class BackupClient(BaseClient):
         BackupVaultName: str,
         SNSTopicArn: str,
         BackupVaultEvents: Sequence[BackupVaultEventType]
-    ) -> None:
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Turns on notifications on a backup vault for the specified topic and events.
 
@@ -770,7 +793,7 @@ class BackupClient(BaseClient):
         IdempotencyToken: str = ...,
         StartWindowMinutes: int = ...,
         CompleteWindowMinutes: int = ...,
-        Lifecycle: "LifecycleTypeDef" = ...,
+        Lifecycle: LifecycleTypeDef = ...,
         RecoveryPointTags: Mapping[str, str] = ...,
         BackupOptions: Mapping[str, str] = ...
     ) -> StartBackupJobOutputTypeDef:
@@ -789,7 +812,7 @@ class BackupClient(BaseClient):
         DestinationBackupVaultArn: str,
         IamRoleArn: str,
         IdempotencyToken: str = ...,
-        Lifecycle: "LifecycleTypeDef" = ...
+        Lifecycle: LifecycleTypeDef = ...
     ) -> StartCopyJobOutputTypeDef:
         """
         Starts a job to create a one-time copy of the specified resource.
@@ -813,7 +836,7 @@ class BackupClient(BaseClient):
         *,
         RecoveryPointArn: str,
         Metadata: Mapping[str, str],
-        IamRoleArn: str,
+        IamRoleArn: str = ...,
         IdempotencyToken: str = ...,
         ResourceType: str = ...
     ) -> StartRestoreJobOutputTypeDef:
@@ -824,7 +847,7 @@ class BackupClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_backup/client/#start_restore_job)
         """
 
-    def stop_backup_job(self, *, BackupJobId: str) -> None:
+    def stop_backup_job(self, *, BackupJobId: str) -> EmptyResponseMetadataTypeDef:
         """
         Attempts to cancel a job to create a one-time backup of a resource.
 
@@ -832,7 +855,9 @@ class BackupClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_backup/client/#stop_backup_job)
         """
 
-    def tag_resource(self, *, ResourceArn: str, Tags: Mapping[str, str]) -> None:
+    def tag_resource(
+        self, *, ResourceArn: str, Tags: Mapping[str, str]
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Assigns a set of key-value pairs to a recovery point, backup plan, or backup
         vault identified by an Amazon Resource Name (ARN).
@@ -841,7 +866,9 @@ class BackupClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_backup/client/#tag_resource)
         """
 
-    def untag_resource(self, *, ResourceArn: str, TagKeyList: Sequence[str]) -> None:
+    def untag_resource(
+        self, *, ResourceArn: str, TagKeyList: Sequence[str]
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Removes a set of key-value pairs from a recovery point, backup plan, or backup
         vault identified by an Amazon Resource Name (ARN) See also: [AWS API
@@ -852,7 +879,7 @@ class BackupClient(BaseClient):
         """
 
     def update_backup_plan(
-        self, *, BackupPlanId: str, BackupPlan: "BackupPlanInputTypeDef"
+        self, *, BackupPlanId: str, BackupPlan: BackupPlanInputTypeDef
     ) -> UpdateBackupPlanOutputTypeDef:
         """
         Updates an existing backup plan identified by its `backupPlanId` with the input
@@ -867,7 +894,7 @@ class BackupClient(BaseClient):
         *,
         FrameworkName: str,
         FrameworkDescription: str = ...,
-        FrameworkControls: Sequence["FrameworkControlTypeDef"] = ...,
+        FrameworkControls: Sequence[FrameworkControlTypeDef] = ...,
         IdempotencyToken: str = ...
     ) -> UpdateFrameworkOutputTypeDef:
         """
@@ -878,7 +905,9 @@ class BackupClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_backup/client/#update_framework)
         """
 
-    def update_global_settings(self, *, GlobalSettings: Mapping[str, str] = ...) -> None:
+    def update_global_settings(
+        self, *, GlobalSettings: Mapping[str, str] = ...
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Updates whether the Amazon Web Services account is opted in to cross-account
         backup.
@@ -888,7 +917,7 @@ class BackupClient(BaseClient):
         """
 
     def update_recovery_point_lifecycle(
-        self, *, BackupVaultName: str, RecoveryPointArn: str, Lifecycle: "LifecycleTypeDef" = ...
+        self, *, BackupVaultName: str, RecoveryPointArn: str, Lifecycle: LifecycleTypeDef = ...
     ) -> UpdateRecoveryPointLifecycleOutputTypeDef:
         """
         Sets the transition lifecycle of a recovery point.
@@ -902,7 +931,7 @@ class BackupClient(BaseClient):
         *,
         ResourceTypeOptInPreference: Mapping[str, bool] = ...,
         ResourceTypeManagementPreference: Mapping[str, bool] = ...
-    ) -> None:
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Updates the current service opt-in settings for the Region.
 
@@ -915,8 +944,8 @@ class BackupClient(BaseClient):
         *,
         ReportPlanName: str,
         ReportPlanDescription: str = ...,
-        ReportDeliveryChannel: "ReportDeliveryChannelTypeDef" = ...,
-        ReportSetting: "ReportSettingTypeDef" = ...,
+        ReportDeliveryChannel: ReportDeliveryChannelTypeDef = ...,
+        ReportSetting: ReportSettingTypeDef = ...,
         IdempotencyToken: str = ...
     ) -> UpdateReportPlanOutputTypeDef:
         """
